@@ -20,8 +20,9 @@ import os.path
 from keystoneauth1 import loading
 from keystonemiddleware import auth_token
 from oslo_config import cfg
-from oslo_config import types
 from oslo_config.cfg import NoSuchOptError
+from oslo_config import types
+from oslo_db import options as db_options
 from oslo_log import log as logging
 from oslo_log import versionutils
 from oslo_middleware import cors
@@ -63,8 +64,12 @@ common_opts = [
                 help='Port the API server will listen on.'),
     cfg.StrOpt('api_paste_config', default="api-paste.ini",
                help='File name for the paste.deploy config for trove-api.'),
-    cfg.BoolOpt('trove_volume_support', default=True,
+    cfg.BoolOpt('trove_volume_support', default=False,
                 help='Whether to provision a Cinder volume for datadir.'),
+    cfg.BoolOpt('volume_rootdisk_support', default=False,
+                help='Whether to provision a Cinder volume for rootdisk.'),
+    cfg.IntOpt('volume_rootdisk_size', default=10,
+               help='Size of volume rootdisk for Database instance'),
     cfg.ListOpt('admin_roles', default=['admin'],
                 help='Roles to add to an admin user.'),
     cfg.BoolOpt('update_status_on_fail', default=True,
@@ -201,6 +206,8 @@ common_opts = [
                     'change.'),
     cfg.IntOpt('state_change_poll_time', default=3,
                help='Interval between state change poll requests (seconds).'),
+    cfg.IntOpt('state_healthy_counts', default=5,
+               help='consecutive success db connections for status HEALTHY'),
     cfg.IntOpt('agent_heartbeat_time', default=10,
                help='Maximum time (in seconds) for the Guest Agent to reply '
                     'to a heartbeat request.'),
@@ -346,7 +353,7 @@ common_opts = [
                           'behalf of the user. This option is ignored.'
     ),
     cfg.StrOpt(
-        'backup_aes_cbc_key', default='',
+        'backup_aes_cbc_key', default='', secret=True,
         help='Default OpenSSL aes_cbc key for decrypting backup data created '
              'prior to Victoria.',
         deprecated_for_removal=True,
@@ -530,66 +537,6 @@ common_opts = [
              'instance'),
 ]
 
-
-database_opts = [
-    cfg.StrOpt('connection',
-               default='sqlite:///trove_test.sqlite',
-               help='SQL Connection.',
-               secret=True,
-               deprecated_name='sql_connection',
-               deprecated_group='DEFAULT'),
-    cfg.IntOpt('idle_timeout',
-               default=3600,
-               deprecated_name='sql_idle_timeout',
-               deprecated_group='DEFAULT'),
-    cfg.BoolOpt('query_log',
-                default=False,
-                deprecated_name='sql_query_log',
-                deprecated_group='DEFAULT',
-                deprecated_for_removal=True),
-    cfg.BoolOpt('sqlite_synchronous',
-                default=True,
-                help='If True, SQLite uses synchronous mode.'),
-    cfg.StrOpt('slave_connection',
-               secret=True,
-               help='The SQLAlchemy connection string to use to connect to the'
-                    ' slave database.'),
-    cfg.StrOpt('mysql_sql_mode',
-               default='TRADITIONAL',
-               help='The SQL mode to be used for MySQL sessions. '
-                    'This option, including the default, overrides any '
-                    'server-set SQL mode. To use whatever SQL mode '
-                    'is set by the server configuration, '
-                    'set this to no value. Example: mysql_sql_mode='),
-    cfg.IntOpt('max_pool_size',
-               help='Maximum number of SQL connections to keep open in a '
-                    'pool.'),
-    cfg.IntOpt('max_retries',
-               default=10,
-               help='Maximum number of database connection retries '
-                    'during startup. Set to -1 to specify an infinite '
-                    'retry count.'),
-    cfg.IntOpt('retry_interval',
-               default=10,
-               help='Interval between retries of opening a SQL connection.'),
-    cfg.IntOpt('max_overflow',
-               help='If set, use this value for max_overflow with '
-                    'SQLAlchemy.'),
-    cfg.IntOpt('connection_debug',
-               default=0,
-               help='Verbosity of SQL debugging information: 0=None, '
-                    '100=Everything.'),
-    cfg.BoolOpt('connection_trace',
-                default=False,
-                help='Add Python stack traces to SQL as comment strings.'),
-    cfg.IntOpt('pool_timeout',
-               help='If set, use this value for pool_timeout with '
-                    'SQLAlchemy.'),
-]
-
-
-# Datastore specific option groups
-
 # Mysql
 mysql_group = cfg.OptGroup(
     'mysql', title='MySQL options',
@@ -652,18 +599,18 @@ mysql_opts = [
                deprecated_reason='Will be replaced by a configuration group '
                'option: long_query_time'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.'),
     cfg.StrOpt(
         'docker_image', default='mysql',
         help='Database docker image.'
     ),
     cfg.StrOpt(
-        'backup_docker_image', default='openstacktrove/db-backup-mysql:1.1.0',
-        help='The docker image used for backup and restore. For mysql, '
-             'the minor version is added to the image name as a suffix before '
-             'creating container, e.g. openstacktrove/db-backup-mysql5.7:1.0.0'
+        'backup_docker_image',
+        sample_default='your-registry/your-repo/db-backup-mysql',
+        help='The docker image used for backup and restore. Trove will uses'
+             'datastore version as the image tag, for example: '
+             'your-registry/your-repo/db-backup-mysql:5.7 is used for mysql'
+             'datastore with version 5.7'
     ),
 ]
 
@@ -733,9 +680,7 @@ percona_opts = [
                'option: long_query_time'),
     cfg.IntOpt('default_password_length',
                default='${mysql.default_password_length}',
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # Percona XtraDB Cluster
@@ -815,9 +760,7 @@ pxc_opts = [
                'option: long_query_time'),
     cfg.IntOpt('default_password_length',
                default='${mysql.default_password_length}',
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 
@@ -877,9 +820,7 @@ redis_opts = [
     cfg.StrOpt('guest_log_exposed_logs', default='',
                help='List of Guest Logs to expose for publishing.'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # Cassandra
@@ -943,9 +884,7 @@ cassandra_opts = [
                help='Class that implements datastore-specific Guest Agent API '
                     'logic.'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.'),
     cfg.BoolOpt('enable_cluster_instance_backup',
                 default=False,
                 help='Allows backup of single instance in the cluster.'),
@@ -1010,9 +949,7 @@ couchbase_opts = [
     cfg.StrOpt('guest_log_exposed_logs', default='',
                help='List of Guest Logs to expose for publishing.'),
     cfg.IntOpt('default_password_length', default=24, min=6, max=24,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # MongoDB
@@ -1091,9 +1028,7 @@ mongodb_opts = [
     cfg.StrOpt('guest_log_exposed_logs', default='',
                help='List of Guest Logs to expose for publishing.'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # PostgreSQL
@@ -1112,8 +1047,11 @@ postgresql_opts = [
     ),
     cfg.StrOpt(
         'backup_docker_image',
-        default='openstacktrove/db-backup-postgresql:1.1.2',
-        help='The docker image used for backup and restore.'
+        sample_default='your-registry/your-repo/db-backup-postgresql',
+        help='The docker image used for backup and restore. Trove will uses'
+             'datastore version as the image tag, for example: '
+             'your-registry/your-repo/db-backup-postgresql:12 is used for'
+             'postgresql datastore with version 12'
     ),
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.',
@@ -1175,9 +1113,7 @@ postgresql_opts = [
                deprecated_reason='Will be replaced by configuration group '
                                  'option: log_min_duration_statement'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # Apache CouchDB
@@ -1228,9 +1164,7 @@ couchdb_opts = [
                 deprecated_name='ignore_dbs',
                 deprecated_group='DEFAULT'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # Vertica
@@ -1297,9 +1231,7 @@ vertica_opts = [
     cfg.IntOpt('min_ksafety', default=0,
                help='Minimum k-safety setting permitted for vertica clusters'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # DB2
@@ -1342,9 +1274,7 @@ db2_opts = [
     cfg.StrOpt('guest_log_exposed_logs', default='',
                help='List of Guest Logs to expose for publishing.'),
     cfg.IntOpt('default_password_length', default=36,
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.')
 ]
 
 # MariaDB
@@ -1428,17 +1358,18 @@ mariadb_opts = [
                     'logic.'),
     cfg.IntOpt('default_password_length',
                default='${mysql.default_password_length}',
-               help='Character length of generated passwords.',
-               deprecated_name='default_password_length',
-               deprecated_group='DEFAULT'),
+               help='Character length of generated passwords.'),
     cfg.StrOpt(
         'docker_image', default='mariadb',
         help='Database docker image.'
     ),
     cfg.StrOpt(
         'backup_docker_image',
-        default='openstacktrove/db-backup-mariadb:1.1.0',
-        help='The docker image used for backup and restore.'
+        sample_default='your-registry/your-repo/db-backup-mariadb',
+        help='The docker image used for backup and restore. Trove will uses'
+             'datastore version as the image tag, for example: '
+             'your-registry/your-repo/db-backup-mariadb:10.3 is used for '
+             'mariadb datastore with version 10.3'
     ),
 ]
 
@@ -1454,7 +1385,7 @@ rpcapi_cap_opts = [
         'taskmanager', default='latest',
         help='Set a version cap for messages sent to taskmanager services'),
     cfg.StrOpt(
-        'guestagent', default='2023.1',
+        'guestagent', default='2024.1',
         help='Set a version cap for messages sent to guestagent services'),
     cfg.StrOpt(
         'conductor', default='latest',
@@ -1480,7 +1411,14 @@ network_opts = [
              'This is needed for the instance initialization. The check is '
              'also necessary when creating public facing instance. A scenario '
              'to set this option False is when using Neutron provider '
-             'network.')
+             'network.'
+    ),
+    cfg.BoolOpt(
+        'network_isolation', default=True,
+        help='whether to plug user defined port to database container.'
+             'This would be useful to isolate user traffic from management'
+             'traffic and to avoid network address conflicts.'
+    )
 ]
 
 service_credentials_group = cfg.OptGroup(
@@ -1546,9 +1484,6 @@ CONF = cfg.CONF
 CONF.register_opts(path_opts)
 CONF.register_opts(versions_opts)
 CONF.register_opts(common_opts)
-
-CONF.register_opts(database_opts, 'database')
-
 CONF.register_group(mysql_group)
 CONF.register_group(percona_group)
 CONF.register_group(pxc_group)
@@ -1582,6 +1517,7 @@ CONF.register_opts(service_credentials_opts, service_credentials_group)
 CONF.register_opts(guest_agent_opts, guest_agent_group)
 
 CONF.register_opts(rpcapi_cap_opts, upgrade_levels)
+db_options.set_defaults(CONF, connection='sqlite://')
 
 profiler.set_defaults(CONF)
 logging.register_options(CONF)
@@ -1595,7 +1531,6 @@ def list_opts():
 
     trove_opts = [
         (None, path_opts + versions_opts + common_opts),
-        ('database', database_opts),
         (mysql_group, mysql_opts),
         (postgresql_group, postgresql_opts),
         (mariadb_group, mariadb_opts),
