@@ -13,28 +13,29 @@
 #    limitations under the License.
 
 import abc
+import os
 import re
 
-import sqlalchemy
-import urllib
-
 from oslo_log import log as logging
 from oslo_utils import encodeutils
+import sqlalchemy
 from sqlalchemy import event
 from sqlalchemy import exc
 from sqlalchemy.sql.expression import text
+import urllib
 
 from trove.common import cfg
-from trove.common import exception
-from trove.common import utils
 from trove.common.configurations import MySQLConfParser
+from trove.common import constants
 from trove.common.db.mysql import models
+from trove.common import exception
 from trove.common.i18n import _
+from trove.common import utils
+from trove.guestagent.common.configuration import ConfigurationManager
+from trove.guestagent.common.configuration import ImportOverrideStrategy
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
 from trove.guestagent.common import sql_query
-from trove.guestagent.common.configuration import ConfigurationManager
-from trove.guestagent.common.configuration import ImportOverrideStrategy
 from trove.guestagent.datastore import service
 from trove.guestagent.utils import docker as docker_util
 from trove.guestagent.utils import mysql as mysql_util
@@ -43,8 +44,9 @@ from trove.instance import service_status
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 ADMIN_USER_NAME = "os_admin"
-CONNECTION_STR_FORMAT = ("mysql+pymysql://%s:%s@localhost/?"
-                         "unix_socket=/var/run/mysqld/mysqld.sock")
+CONNECTION_STR_FORMAT = ("mysql+pymysql://%s:%s@localhost/?" +
+                         f"unix_socket={constants.MYSQL_HOST_SOCKET_PATH}"
+                         "/mysqld.sock")
 ENGINE = None
 INCLUDE_MARKER_OPERATORS = {
     True: ">=",
@@ -107,7 +109,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         LOG.debug("Associating dbs to user %(name)s at %(host)s.",
                   {'name': user.name, 'host': user.host})
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             q = sql_query.Query()
             q.columns = ["grantee", "table_schema"]
             q.tables = ["information_schema.SCHEMA_PRIVILEGES"]
@@ -124,7 +126,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         """Change the passwords of one or more existing users."""
         LOG.debug("Changing the password of some users.")
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for item in users:
                 LOG.debug("Changing password for user %s.", item)
                 user_dict = {'_name': item['name'],
@@ -149,7 +151,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
 
         if new_name or new_host or new_password:
             with mysql_util.SqlClient(
-                self.mysql_app.get_engine(), use_flush=True) as client:
+                    self.mysql_app.get_engine(), use_flush=True) as client:
                 if new_password is not None:
                     uu = sql_query.SetPassword(
                         user.name, host=user.host,
@@ -169,7 +171,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
     def create_databases(self, databases):
         """Create the list of specified databases."""
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for item in databases:
                 mydb = models.MySQLSchema.deserialize(item)
                 mydb.check_create()
@@ -185,7 +187,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
            specified databases.
         """
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for item in users:
                 user = models.MySQLUser.deserialize(item)
                 user.check_create()
@@ -206,7 +208,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
     def delete_database(self, database):
         """Delete the specified database."""
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             mydb = models.MySQLSchema.deserialize(database)
             mydb.check_delete()
             dd = sql_query.DropDatabase(mydb.name)
@@ -221,7 +223,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
 
     def delete_user_by_name(self, name, host='%'):
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             du = sql_query.DropUser(name, host=host)
             t = text(str(du))
             LOG.debug("delete_user_by_name: %s", t)
@@ -248,7 +250,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
                                        {'user': username, 'reason': err_msg}
                                        )
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             q = sql_query.Query()
             q.columns = ['User', 'Host']
             q.tables = ['mysql.user']
@@ -271,7 +273,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         user = self._get_user(username, hostname)
         mydb = None  # cache the model as we just want name validation
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for database in databases:
                 try:
                     if mydb:
@@ -375,7 +377,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
                   "be omitted from the listing: %s", ignored_user_names)
         users = []
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             iq = sql_query.Query()  # Inner query.
             iq.columns = ['User', 'Host', "CONCAT(User, '@', Host) as Marker"]
             iq.tables = ['mysql.user']
@@ -418,7 +420,7 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         """Revoke a user's permission to use a given database."""
         user = self._get_user(username, hostname)
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             r = sql_query.Revoke(database=database,
                                  user=user.name,
                                  host=user.host)
@@ -477,7 +479,7 @@ class BaseMySqlApp(service.BaseDbApp):
     def execute_sql(self, sql_statement, use_flush=False):
         LOG.debug("Executing SQL: %s", sql_statement)
         with mysql_util.SqlClient(
-            self.get_engine(), use_flush=use_flush) as client:
+                self.get_engine(), use_flush=use_flush) as client:
             return client.execute(sql_statement)
 
     def get_data_dir(self):
@@ -589,7 +591,8 @@ class BaseMySqlApp(service.BaseDbApp):
         user = "%s:%s" % (CONF.database_service_uid, CONF.database_service_uid)
 
         # Create folders for mysql on localhost
-        for folder in ['/etc/mysql', '/var/run/mysqld']:
+        for folder in ['/etc/mysql', constants.MYSQL_HOST_SOCKET_PATH,
+                       '/etc/mysql/mysql.conf.d']:
             operating_system.ensure_directory(
                 folder, user=CONF.database_service_uid,
                 group=CONF.database_service_uid, force=True,
@@ -597,8 +600,8 @@ class BaseMySqlApp(service.BaseDbApp):
 
         volumes = {
             "/etc/mysql": {"bind": "/etc/mysql", "mode": "rw"},
-            "/var/run/mysqld": {"bind": "/var/run/mysqld",
-                                "mode": "rw"},
+            constants.MYSQL_HOST_SOCKET_PATH: {"bind": "/var/run/mysqld",
+                                               "mode": "rw"},
             "/var/lib/mysql": {"bind": "/var/lib/mysql", "mode": "rw"},
         }
         if extra_volumes:
@@ -611,12 +614,18 @@ class BaseMySqlApp(service.BaseDbApp):
             for port in port_range:
                 ports[f'{port}/tcp'] = port
 
+        if CONF.network_isolation and \
+                os.path.exists(constants.ETH1_CONFIG_PATH):
+            network_mode = constants.DOCKER_HOST_NIC_MODE
+        else:
+            network_mode = constants.DOCKER_BRIDGE_MODE
+
         try:
             docker_util.start_container(
                 self.docker_client,
                 image,
                 volumes=volumes,
-                network_mode="bridge",
+                network_mode=network_mode,
                 ports=ports,
                 user=user,
                 environment={
@@ -663,7 +672,8 @@ class BaseMySqlApp(service.BaseDbApp):
         LOG.info("Restarting mysql")
 
         # Ensure folders permission for database.
-        for folder in ['/etc/mysql', '/var/run/mysqld']:
+        for folder in ['/etc/mysql', constants.MYSQL_HOST_SOCKET_PATH,
+                       '/etc/mysql/mysql.conf.d']:
             operating_system.ensure_directory(
                 folder, user=CONF.database_service_uid,
                 group=CONF.database_service_uid, force=True,
@@ -862,7 +872,7 @@ class BaseMySqlRootAccess(object):
         """
         user = models.MySQLUser.root(password=root_password)
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             try:
                 cu = sql_query.CreateUser(user.name, host=user.host)
                 t = text(str(cu))
@@ -873,7 +883,7 @@ class BaseMySqlRootAccess(object):
                 LOG.debug(err)
 
         with mysql_util.SqlClient(
-            self.mysql_app.get_engine(), use_flush=True) as client:
+                self.mysql_app.get_engine(), use_flush=True) as client:
             uu = sql_query.SetPassword(
                 user.name, host=user.host, new_password=user.password,
                 ds=CONF.datastore_manager, ds_version=CONF.datastore_version
